# Contribution Guide

[[_TOC_]]

## General Remarks

For a developer install via pip in editable mode:

```bash
git clone git@codebase.helmholtz.cloud:fwdc/python.git
pip install --editable python[dev]
```

## Static Code Analysis (Linting)

To run the static code checks install `pre-commit`[^5] and activate the git
hooks

```shell
pre-commit install
```

MegaLinter[^1] is used for linting various formats like Python, Shell, JSON,
Markdown and other. Spellchecking is done with `cspell`[^2] for all strings and
comments (included in MegaLinter). If variables are used inside strings or
comments or in the documentation header they have to be added to the `cspell`
dictionary by editing `etc/cspell-dictionary.txt`. The dictionary can be sorted
alphabetically by

```shell
sort -u cspell-dictionary.txt -o cspell-dictionary.txt
```

The unique option `-u` removes duplicates automatically.

## Unit Testing

For unit tests `pytest` is used, and can be run as follows

```shell
pytest --cov
```

For more information on pytest see: <https://docs.pytest.org>

## Documentation

To build the documentation run

```bash
sphinx-apidoc -f -o docs multiphasepy
sphinx-build -b html docs docs/_build
```

documentation is done according to Google Python Style Guide[^3] and for type
hinting use PEP0484[^4]. An example is given below

```python
def func(arg1: int, arg2: str) -> bool:
    """Summary line.

    Extended description of function.

    Args:
        arg1: Description of arg1
        arg2: Description of arg2

    Returns:
        Description of return value

    """
    return True
```

## Deployment

The repository is deployed as PyPi package. The configuration for
the PyPi package is defined in `pyproject.toml`. To build the
PyPi package simply run

```bash
python -m build
```

---
[^1]: <https://oxsecurity.github.io/megalinter/latest>
[^2]: <https://cspell.org>
[^3]: <https://google.github.io/styleguide/pyguide.html>
[^4]: <https://peps.python.org/pep-0484/#arbitrary-argument-lists-and-default-argument-values>
[^5]: <https://pre-commit.com>
