# README for Multiphase Python Repository by HZDR

[[_TOC_]]

The python package provides several routines and scripts required to operate
the code and cases repositories containing additional code and set-ups for the
open-source software released by the OpenFOAM Foundation. This includes among
others utilities for pre- and post-processing of simulation cases, utilities
to launch virtual environments containing the source code, and utilities to
operate the continuous integration and continuous development environment in a
self-hosted Gitlab instance.

## Utilities

The module contains several stand-alone python scripts. For more information on
each script use the `--help` option.

| Name       | Description                                                                         |
|------------|-------------------------------------------------------------------------------------|
| mpyconv    | Converts data files between readable and writable formates defined in multiphasepy. |
| mpydocker  | Launch a customizable docker container for a given image from the registry.         |
| mpyfuzzy   | Evaluate goodness for a simulation case by using fuzzy logic.                       |
| mpykcheck  | Checks keywords in a simulation case against a reference list.                      |
| mpypost    | Run some math as post-processing on data files.                                     |
| mpypublish | Publish a software publication in Rossendorf Data Repository (Rodare).              |
| mpyrpcmp   | Compares two repositories and print result with respect to the left repository.     |
| mpyshrun   | Wraps a given command similar to runApplication from RunFunctions.                  |

## Installation

Install prerequisites via

```bash
sudo apt-get update
sudo apt-get install python3 python3-venv pipx git
pipx ensurepath
```

Afterwards, the package can be installed easily via pipx[^1] from the Gitlab
PyPi. For a simple and convenient usage add the following to
`$HOME/.config/pip/pip.conf`

```bash
[global]
extra-index-url = https://codebase.helmholtz.cloud/api/v4/projects/8786/packages/pypi/simple
```

and then install the package with

```bash
pipx install multiphasepy
```

or upgrade with

```bash
pipx upgrade multiphasepy
```

If required pipx can install extra (recommended) dependencies for python

```bash
pipx install multiphasepy[extra]
```

Note, you have to replace `extra` with an extra from the table below

| Extra | Description                                                                    |
|-------|--------------------------------------------------------------------------------|
| all   | All extra packages                                                             |
| rec   | Packages recommended for daily usage, e.g., to run a workflow with snakemake   |
| dev   | Packages required for development of the package, e.g., pytest and ruff linter |

## Links and References

[^1]: <https://github.com/pypa/pipx>