# This file is part of the Multiphase Python Repository by HZDR.
#
# Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
# Website: https://hzdr.de
#
# Multiphase Python Repository by HZDR is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Multiphase Python Repository by HZDR is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with the Multiphase Python Repository by HZDR. If not, see
# <http://www.gnu.org/licenses/>.

"""Test module to test metric calculations."""

from pytest import approx
import numpy as np
from multiphasepy import metrics

datax = np.array([1, 2, 3, 5, 8])
datay = np.array([0.11, 0.12, 0.13, 0.15, 0.18])
coord = np.array([0, 1, 2, 3, 4])


def test_mre():
    """Test for mean relative error."""
    assert metrics.mre(datax, datay) == approx(26.5362318)


def test_pcc():
    """Test for pearson correlation coefficient."""
    assert metrics.pcc(datax, datay) == approx(1)


def test_calc():
    """Test for metric calculation interface."""
    assert metrics.calc(
        "pcc",
        np.column_stack((coord, datax)),
        np.column_stack((coord, datay)),
        interpolate=False,
    ) == approx(1)
