# This file is part of the Multiphase Python Repository by HZDR.
#
# Copyright (C) 2023 by Helmholtz-Zentrum Dresden-Rossendorf e.V. (HZDR),
# Website: https://hzdr.de
#
# Multiphase Python Repository by HZDR is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Multiphase Python Repository by HZDR is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with the Multiphase Python Repository by HZDR. If not, see
# <http://www.gnu.org/licenses/>.

"""Test module to compare two repositories."""

from filecmp import dircmp
from os import path
from multiphasepy import rpcmp


def test_analyse():
    """Test for analyse function."""
    # Create dircmp object for test folder
    dcmp = dircmp("tests/data/rpcmp/left", "tests/data/rpcmp/right")

    # Create empty lists
    new = []
    copy = []
    modified = []

    # Analyse repositories
    rpcmp.analyse(dcmp, new, copy, modified)

    # Make all path relative
    for i, entry in enumerate(new):
        new[i] = path.relpath(entry, start=dcmp.left)
    for i, entry in enumerate(copy):
        copy[i] = path.relpath(entry, start=dcmp.left)
    for i, entry in enumerate(modified):
        modified[i] = path.relpath(entry, start=dcmp.left)

    # Sort entries
    new.sort()
    copy.sort()
    modified.sort()

    # Compare results
    assert new == [
        "new.C",
        "new.sh",
        "new/new.C",
        "new/new.sh",
        "new/newDict",
        "newDict",
    ]
    assert copy == [
        "copy.C",
        "copy.sh",
        "copy/copy.C",
        "copy/copy.sh",
        "copy/copyDict",
        "copyDict",
    ]
    assert modified == [
        "modified.C",
        "modified.sh",
        "modified/modified.C",
        "modified/modified.sh",
        "modified/modifiedDict",
        "modifiedDict",
    ]
